@@ -39,7 +39,7 @@
 -- This is very similar to 'ErrorT' and 'MonadError', but based on features of
 -- "Control.Exception". In particular, it handles the complex case of
 -- asynchronous exceptions by including 'mask' in the typeclass. Note that the
--- extensible extensions feature relies on the RankNTypes language extension.
+-- extensible exceptions feature relies on the RankNTypes language extension.
 --------------------------------------------------------------------
 
 module Control.Monad.Catch (
@@ -93,6 +93,8 @@ import Control.Monad.Trans.Cont (ContT)
 import Control.Monad.Trans.Identity
 import Control.Monad.Reader as Reader
 
+import Language.Haskell.TH.Syntax (Q)
+
 #if __GLASGOW_HASKELL__ < 706
 import Prelude hiding (catch, foldr)
 import Data.Foldable
@@ -183,6 +185,8 @@ instance MonadThrow Maybe where
   throwM _ = Nothing
 instance e ~ SomeException => MonadThrow (Either e) where
   throwM = Left . toException
+instance MonadThrow Q where
+  throwM = fail . show
 
 instance MonadThrow IO where
   throwM = ControlException.throwIO
